# django-whatsapp

[![PyPI - Version](https://img.shields.io/pypi/v/django-whatsapp.svg)](https://pypi.org/project/django-whatsapp)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-whatsapp.svg)](https://pypi.org/project/django-whatsapp)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install django-whatsapp
```

## License

`django-whatsapp` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
